
# Slot: object


the population that form the object of the association

URI: [biolink:population_to_population_association_object](https://w3id.org/biolink/vocab/population_to_population_association_object)


## Domain and Range

[PopulationToPopulationAssociation](PopulationToPopulationAssociation.md) &#8594;  <sub>1..1</sub> [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [PopulationToPopulationAssociation](PopulationToPopulationAssociation.md)
